@@ -1,13 +1,12 @@
 package MooseX::Getopt::GLD;
-BEGIN {
-  $MooseX::Getopt::GLD::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: A Moose role for processing command line options with Getopt::Long::Descriptive
-$MooseX::Getopt::GLD::VERSION = '0.62';
+
+our $VERSION = '0.75';
+
 use strict;
 use warnings;
-use MooseX::Role::Parameterized;
-use Getopt::Long::Descriptive 0.081;
+use MooseX::Role::Parameterized 1.01;
+use Getopt::Long::Descriptive 0.088;
 with 'MooseX::Getopt::Basic';
 use namespace::autoclean;
 
@@ -28,7 +27,7 @@ role {
 
     # captures the options: --help --usage --? -? -h
     has help_flag => (
-        is => 'ro', isa => 'Bool',
+        is => 'ro',
         traits => ['Getopt'],
         cmd_flag => 'help',
         cmd_aliases => [ qw(usage ? h) ],
@@ -92,15 +91,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Stevan Little Infinity Interactive, Inc
-
 =head1 NAME
 
 MooseX::Getopt::GLD - A Moose role for processing command line options with Getopt::Long::Descriptive
 
 =head1 VERSION
 
-version 0.62
+version 0.75
 
 =head1 SYNOPSIS
 
@@ -137,6 +134,17 @@ C<getopt_conf>. This parameter is an ArrayRef of strings, which are
 L<Getopt::Long> configuration options (see "Configuring Getopt::Long" in
 L<Getopt::Long>)
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Getopt>
+(or L<bug-MooseX-Getopt@rt.cpan.org|mailto:bug-MooseX-Getopt@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
